﻿/*
	S. 66.
	Adrián Patrik, 12. évf.
	Baross Gábor Középiskola, Szakiskola és Kollégium, Debrecen
*/

#define _CRT_SECURE_NO_WARNINGS

#include <stdio.h>

// Csúcsok maximális száma
#define MAXN 50000
// Utak maximális száma
#define MAXQ 50000

#define GRAY 1
#define BLACK 2

// Láncolt lista egy elemét leíró adattípus
typedef struct
{
	// A listaelem értéke
	int value;
	// A következő listaelem indexe
	int next;
} list_t;

// A gráf csúcsait leíró adattípus
typedef struct
{
	// A szomszédok listájának fejcíme
	int neighbours_head;
	// Az áthaladó útvonalak listájának címe
	int paths_head;
	// A teljes töltése
	int charge;
	// Színe
	unsigned char color;
	// Pillanatnyi ős-reprezentánsa
	int ancestor;
	// A csúcs szülője
	int parent;
} node_t;

// Egy útvonalat leíró adattípus
typedef struct
{
	// Az útvonal két végpontja
	int i, j;
	// Az útvonal többlettöltése
	int charge;
} path_t;

// A gráf csúcsai
node_t nodes[MAXN];
// Az utak leírása
path_t paths[MAXQ];
// A szomszédsági listák elemei
list_t neighbour_list_nodes[2 * MAXN + 1];
// Az útvonallisták elemei
list_t path_list_nodes[2 * MAXN + 1];

int find_ancestor(int i)
{
	// Ha önmaga az őse
	if(nodes[i].ancestor == i)
		// Akkor önmagát adjuk vissza
		return i;
	// Egyébként az ősének az ősét, de tömörítünk
	return nodes[i].ancestor = find_ancestor(nodes[i].ancestor);
}

int processTree(int i)
{
	// Csúcsindexek
	int j, k;
	// Segédváltozók
	int c;
	// A továbbvitt töltés
	int passed_on_charge;

	// Szürkére színezzük a csúcsot
	nodes[i].color = GRAY;
	// Önmaga az ős-reprezentánsa
	nodes[i].ancestor = i;

	// Bejárjuk a szomszédait
	for(c = nodes[i].neighbours_head; c; c = neighbour_list_nodes[c].next)
	{
		// Külön változóba mentjük az éppen vizsgált szomszéd indexét
		j = neighbour_list_nodes[c].value;
		
		// Ha a csúcs a szülője
		if(nodes[j].color == GRAY)
			// Nem foglalkozunk vele
			continue;

		// Beállítjuk a gyermekének a szülőjét
		nodes[j].parent = i;

		// Továbbléptetjük a keresést
		// Hozzáadjük a részfából örökölt töltést
		nodes[i].charge += processTree(j);

		// Alárendeljük a gyermekét
		nodes[j].ancestor = i;
	}

	// Az adott csúcsot feldolgozottnak tekintjük
	nodes[i].color = BLACK;

	// A továbbvitt töltést a saját töltésére állítjuk
	passed_on_charge = nodes[i].charge;

	// Végignézzük az összes útvonalat
	for(c = nodes[i].paths_head; c; c = path_list_nodes[c].next)
	{
		// Megkeressük az útvonal másik végpontját
		if(paths[path_list_nodes[c].value].i == i)
			j = paths[path_list_nodes[c].value].j;
		else
			j = paths[path_list_nodes[c].value].i;

		// Ha a párját már feldolgoztuk
		if(nodes[j].color == BLACK)
		{
			// Megkeressük a reprezentánsát
			// k a legközelebbi közös elődjük
			k = find_ancestor(j);

			// Ha az útvonal másik vége ebben a részfában van
			if(k == i)
			{
				// Külön kezeljük azt az esetet, ha az útvonal két végpontja egybeesik
				if(i == j)
				{
					nodes[i].charge += paths[path_list_nodes[c].value].charge;
					continue;
				}

				// Ennek az útvonalnak a töltését már nem kell továbbadni
				passed_on_charge -= paths[path_list_nodes[c].value].charge;
			}
			// És ha nem
			else
			{
				passed_on_charge += paths[path_list_nodes[c].value].charge;
				nodes[i].charge += paths[path_list_nodes[c].value].charge;
				nodes[k].charge -= paths[path_list_nodes[c].value].charge;
				// Ha a szülője létezik, akkor még egyszer le kell vonni
				if(k)
					nodes[nodes[k].parent].charge -= paths[path_list_nodes[c].value].charge;
			}	
		}
		// Egyébként csak elindítjuk a töltést
		else
		{
			passed_on_charge += paths[path_list_nodes[c].value].charge;
			nodes[i].charge += paths[path_list_nodes[c].value].charge;
		}
	}

	return passed_on_charge;
}

int main(int argc, char *argv[])
{
	// A gráf csúcsainak és a villámok darabszáma
	int n, q;
	// Segédváltozók
	int i, j, k, c;

	// Beolvassuk a gráf csúcsainak számát
	scanf("%d", &n);
	for(k = 1; k < n; k ++)
	{
		// Beolvassuk az él két végpontját
		scanf("%d %d", &i, &j);

		// Elhelyezzük az indexeket egymás szomszédsági listájában
		neighbour_list_nodes[2 * k - 1].value = j;
		neighbour_list_nodes[2 * k - 1].next = nodes[i].neighbours_head;
		nodes[i].neighbours_head = 2 * k - 1;

		neighbour_list_nodes[2 * k].value = i;
		neighbour_list_nodes[2 * k].next = nodes[j].neighbours_head;
		nodes[j].neighbours_head = 2 * k;
	}

	// Beolvassuk a villámok számát
	scanf("%d", &q);
	for(k = 0; k < q; k ++)
	{
		scanf("%d %d %d", &i, &j, &c);
		
		// Eltároljuk az útvonalat
		paths[k].i = i;
		paths[k].j = j;
		paths[k].charge = c;

		// Hozzáadjuk a csúcsok útvonallistáihoz
		path_list_nodes[2 * k + 1].value = k;
		path_list_nodes[2 * k + 1].next = nodes[i].paths_head;
		nodes[i].paths_head = 2 * k + 1;

		// El kell kerülnünk a kétszeres tárolást
		if(i != j)
		{
			path_list_nodes[2 * k + 2].value = k;
			path_list_nodes[2 * k + 2].next = nodes[j].paths_head;
			nodes[j].paths_head = 2 * k + 2;
		}
	}

	// Elindítjuk a feldolgozást
	processTree(0);

	// Végigmegyünk a csúcsokon
	for(k = 0; k < n; k ++)
		// És kiírjuk a töltésüket
		printf("%d\n", nodes[k].charge);

	return 0;
}
